IIIFとOCRを組み合わせたツール
================

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->
<!-- This file will become your README and also the index of your documentation. -->

## Install

``` sh
pip install ocr_iiif_tools
```

## How to use

under construction
